@@ -18,7 +18,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include <math.h>
 
 #include "ADM_utilities/default.h"
@@ -57,7 +57,7 @@ const char* audioFilterGetIndexedName(uint32_t i);
 typedef struct externalSource
 {
  AudioSource type;
- char *name;       
+ const char *name;
 }externalSource;
 
 static const externalSource Sources[]=
@@ -70,7 +70,7 @@ static const externalSource Sources[]=
 };
 typedef struct Mixer_String
 {
-  char         *name;
+  const char         *name;
   CHANNEL_CONF conf;
 };
 
