@@ -16,7 +16,7 @@
  ***************************************************************************/
 #ifndef __CODECS__
 #define __CODECS__
-#include "ADM_library/ADM_image.h"
+#include "ADM_image.h"
 
 #define AVI_KEY_FRAME	0x10
 #define AVI_B_FRAME	0x4000	// hopefully it is not used..
@@ -31,7 +31,8 @@
 
 */
 
-#include "ADM_library/ADM_bitstream.h"
+#include "ADM_bitstream.h"
+#include "ADM_compressedImage.h"
 class decoders
 {
 protected:
@@ -59,9 +60,7 @@ public:
   virtual void setParam (void)
   {
   };
-  virtual uint8_t uncompress (uint8_t * in, ADMImage * out, uint32_t len,
-			      uint32_t * flagz);
-//                      virtual uint8_t         getLastQ( uint8_t *q) { *q=_lastQ;return 1;}
+  virtual uint8_t uncompress (ADMCompressedImage * in, ADMImage * out)=0;
 
   // does this codec *possibly* can have b-frame ?
   virtual uint8_t dontcopy (void)
@@ -94,9 +93,18 @@ public:
     return 1;
   };
 };
+/* Dummy decoder in case we don't have the desired one */
+class decoderEmpty : public decoders
+{
+protected:
+public:
+    decoderEmpty (uint32_t w, uint32_t h) : decoders(w,h) {};
+    uint8_t uncompress (ADMCompressedImage * in, ADMImage * out) {return 1;}
+
+};
 
 decoders *getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
-		      uint8_t * extraData);
+		      uint8_t * extraData,uint32_t bpp=0);
 decoders *getDecoderVopPacked (uint32_t fcc, uint32_t w, uint32_t h,
 			       uint32_t extraLen, uint8_t * extraData);
 decoders *getDecoderH264noLogic (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
@@ -122,6 +130,8 @@ decoders *getCoder (uint32_t fcc, uint32_t w, uint32_t h);
 uint8_t isMpeg4Compatible (uint32_t fourcc);
 uint8_t isH264Compatible (uint32_t fourcc);
 uint8_t isMSMpeg4Compatible (uint32_t fourcc);
+uint8_t isDVCompatible (uint32_t fourcc);
+
 /*----------------------------------------------------------*/
 class encoder
 {
