@@ -155,6 +155,23 @@ isMSMpeg4Compatible (uint32_t fourcc)
 
   return divx3;
 
+#undef CHECK
+}
+uint8_t isVP6Compatible (uint32_t fourcc)
+{
+
+#define CHECK(x) if(fourCC::check(fourcc,(uint8_t *)x)) \
+						{divx3=1; }
+
+  uint8_t divx3 = 0;
+
+  CHECK ("VP6F");
+  CHECK ("VP6 ");
+  CHECK ("VP61");
+  CHECK ("VP62");
+
+  return divx3;
+
 #undef CHECK
 }
 uint8_t
@@ -231,8 +248,8 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
     {
       return (decoders *) (new decoderFFFLV1 (w, h,extraLen, extraData));
     }
-  
-    
+
+
 #ifdef USE_FFMPEG
   if (fourCC::check (fcc, (uint8_t *) "H263"))
     {
@@ -287,7 +304,7 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
 
       return (decoders *) (new decoderFFWMV1 (w, h, extraLen, extraData));
     }
-  
+
   if (fourCC::check (fcc, (uint8_t *) "WMV3"))
     {
 
@@ -370,8 +387,8 @@ if (fourCC::check (fcc, (uint8_t *) "MJPG")
       return (decoders *) (new decoderFFAMV (w, h,extraLen,extraData));
     }
 
-    
-  if (fourCC::check (fcc, (uint8_t *) "VP6F"))
+
+  if (isVP6Compatible(fcc))
     {
       printf ("\n using VP6F codec\n");
       return (decoders *) (new decoderFFVP6F (w, h,extraLen,extraData));
@@ -382,14 +399,14 @@ if (fourCC::check (fcc, (uint8_t *) "MJPG")
     {
       // RGB 16 Codecs
       printf ("\n using RGB codec\n");
-      return (decoders *) (new decoderRGB16 (w, h, 0, bpp));
+      return (decoders *) (new decoderRGB16 (w, h, 1, bpp));
 
     }
  if ((fcc == 0) || fourCC::check (fcc, (uint8_t *) "DIB "))
     {
       // RGB 16 Codecs
-      printf ("\n using RGB-DIB codec\n");
-      return (decoders *) (new decoderRGB16 (w, h, 1, bpp));
+      printf ("\n using DIB codec\n");
+      return (decoders *) (new decoderRGB16 (w, h, 0, bpp));
 
     }
   if (isMpeg12Compatible (fcc))
@@ -409,7 +426,7 @@ if (fourCC::check (fcc, (uint8_t *) "MJPG")
 	{
 	  return (decoders *) (new decoderMpeg (w, h, extraLen, extraData));
 	}
-      //  
+      //
     }
 
   // default : null decoder
