@@ -51,6 +51,7 @@ typedef struct ADM_x264Param
   uint32_t Method;
   uint32_t AR_Num;
   uint32_t AR_Den;
+  uint8_t  AR_AsInput;
   uint32_t DeblockingFilter;
   int32_t  Strength;
   int32_t  Threshold;
@@ -60,8 +61,15 @@ typedef struct ADM_x264Param
   uint32_t MixedRefs;
   uint32_t NoiseReduction;
   //
-
-  //
+  uint32_t idc;
+  // Sadarax ui
+  uint32_t fastPSkip;
+  uint32_t DCTDecimate;
+  uint32_t interlaced;
+  
+  uint32_t vbv_max_bitrate;
+  uint32_t vbv_buffer_size;
+  uint32_t vbv_buffer_init; /* In % to be translated to float between 0 and 1 */
 
 } ADM_x264Param;
 
