@@ -103,6 +103,12 @@ uint8_t DIA_x264(COMPRES_PARAMS *config)
         specific=(ADM_x264Param *)config->extraSettings;
 
         dialog=create_dialog1();
+
+		gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+											GTK_RESPONSE_OK,
+											GTK_RESPONSE_CANCEL,
+											-1);
+
         gtk_register_dialog(dialog);
         gtk_dialog_add_action_widget (GTK_DIALOG (dialog), WID(buttonResetDaults),ACTION_LOAD_DEFAULT);
 
@@ -1182,10 +1188,10 @@ create_dialog1 (void)
   comboboxDirectMode = gtk_combo_box_new_text ();
   gtk_widget_show (comboboxDirectMode);
   gtk_box_pack_start (GTK_BOX (hbox1), comboboxDirectMode, FALSE, TRUE, 0);
-  gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("Auto"));
-  gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("Temporal"));
-  gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("Spatial"));
   gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("None"));
+  gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("Spatial"));
+  gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("Temporal"));
+  gtk_combo_box_append_text (GTK_COMBO_BOX (comboboxDirectMode), QT_TR_NOOP("Auto"));
 
   label20 = gtk_label_new (QT_TR_NOOP("<b>B-Frames</b>"));
   gtk_widget_show (label20);
