@@ -22,7 +22,7 @@ void UI_setVProcessToggleStatus( uint8_t status );
 void UI_iconify( void );
 void UI_deiconify( void );
 
-uint32_t UI_readCurFrame( void );
+int UI_readCurFrame( void );
 int UI_readCurTime(uint16_t &hh, uint16_t &mm, uint16_t &ss, uint16_t &ms);
 void UI_JumpDone(void);
 
