@@ -196,3 +196,14 @@ uint8_t *dst,*dstu,*dstv,*src,*srcu,*srcv;
 	        data->copyInfo(_uncompressed);
               return 1;
 }
+uint8_t AVDMVideoSmooth::configure( AVDMGenericVideoStream *instream)
+{
+UNUSED_ARG(instream);
+
+SMOOTH_PARAMS *par;
+	
+//     	par=_param;
+     	//return((uint8_t)getSmoothParams(&par->radius,&par->blend));
+	return 1;
+#warning FIXME , CODE REMOVED AMD64/GCC4
+}
